Module for the course of numeric methods in the University of Antioquia.

Authors:
	- Created by Juan Esteban Sierra Aguilar, Electrical engineering student.
	- Created by Juan Fernando Paniagua Osorio, Electrical engineering student.
	- Advised by Jaime Alejandro Valencia Velazquez, Electrical engineering.
	
Index:
	- M1: Models and computational error.
	- M2: Linear ecuactions.
	- M3: Non linear ecuactions.
		- Optimization.
	- M4: Curve fit & interpolation.
	- M5: numeric integration and derivation.
	- M6: Ordinary diferencial ecuactions.
	- M7: Parcial diferencial ecuactions.

Module index:
	- error
	- linear
	- nonlinear
		- optimize
	- curve
		- fit
		- interpolation
	- diff
		- derivation
		- integration
	- ode
	- pde
	
Example: metnumudea.curve.fit.somefunction(some_args)

TODO:
	- Py2to3

References:
	- https://python-packaging.readthedocs.io/en/latest/minimal.html